# cog-huggingface-template

Tools to help deploy Hugging Face models to replicate.


## Requirements

- GPU environment
- [Cog](https://cog.run)

## Installation

### PyPI Install

```
pip install cog_hf_template
```

### Dev Install

Clone the repo:

```
git clone https://github.com/replicate/cog-huggingface-template
cd cog-huggingface-template
pip install -e .
```

Run tests

```
pip install pytest
```

```
pytest -vv tests
```

## Usage

For now, see the [examples directory](examples) for a working example.